% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Regressor.R
\name{Regressor}
\alias{Regressor}
\title{\code{Regressor} class}
\description{
The \code{Regressor} class contains supervised regression models
}
\details{
This class implements models:

\describe{
\item{lm}{Linear model}
\item{bcn}{see https://www.researchgate.net/publication/380760578_Boosted_Configuration_neural_Networks_for_supervised_classification}
\item{extratrees}{Extremely Randomized Trees; see https://link.springer.com/article/10.1007/s10994-006-6226-1}
\item{glmnet}{Elastic Net Regression; see https://glmnet.stanford.edu/}
\item{krr}{Kernel Ridge Regression; see for example https://www.jstatsoft.org/article/view/v079i03} (but the implementation is different)
\item{ranger}{Random Forest; see https://www.jstatsoft.org/article/view/v077i01}
\item{ridge}{Ridge regression; see https://arxiv.org/pdf/1509.09169}
\item{xgboost}{a scalable tree boosting system see https://arxiv.org/abs/1603.02754}
\item{svm}{Support Vector Machines, see https://cran.r-project.org/web/packages/e1071/vignettes/svmdoc.pdf}
\item{rvfl}{Random Vector Functional Network, see https://www.researchgate.net/publication/332292006_Online_Bayesian_Quasi-Random_functional_link_networks_application_to_the_optimization_of_black_box_functions}
}
}
\section{Super class}{
\code{\link[learningmachine:Base]{learningmachine::Base}} -> \code{Regressor}
}
\section{Public fields}{
\if{html}{\out{<div class="r6-fields">}}
\describe{
\item{\code{name}}{name of the class}

\item{\code{type}}{type of supervised learning method implemented}

\item{\code{model}}{fitted model}

\item{\code{method}}{supervised learning method in c('lm', 'ranger',
'extratrees', 'ridge', 'bcn', 'glmnet', 'krr',
'xgboost', 'svm')}

\item{\code{X_train}}{training set features; do not modify by hand}

\item{\code{y_train}}{training set response; do not modify by hand}

\item{\code{pi_method}}{type of prediction interval in c("splitconformal",
"kdesplitconformal", "bootsplitconformal", "jackknifeplus",
"kdejackknifeplus", "bootjackknifeplus", "surrsplitconformal",
"surrjackknifeplus")}

\item{\code{level}}{an integer; the level of confidence (default is 95, for 95 per cent)
for prediction intervals}

\item{\code{B}}{an integer; the number of simulations when 'level' is not NULL}

\item{\code{nb_hidden}}{number of nodes in the hidden layer, for construction of a quasi-
randomized network}

\item{\code{nodes_sim}}{type of 'simulations' for hidden nodes, if \code{nb_hidden} > 0;
takes values in c("sobol", "halton", "unif")}

\item{\code{activ}}{activation function's name for the hidden layer, in the construction
of a quasi-randomized network; takes values in c("relu", "sigmoid", "tanh", "
leakyrelu", "elu", "linear")}

\item{\code{engine}}{contains fit and predic lower-level methods for the given \code{method};
do not modify by hand}

\item{\code{params}}{additional parameters passed to \code{method} when calling \code{fit}
do not modify by hand}

\item{\code{seed}}{an integer; reproducibility seed for methods that include
randomization}
}
\if{html}{\out{</div>}}
}
\section{Methods}{
\subsection{Public methods}{
\itemize{
\item \href{#method-Regressor-new}{\code{Regressor$new()}}
\item \href{#method-Regressor-fit}{\code{Regressor$fit()}}
\item \href{#method-Regressor-predict}{\code{Regressor$predict()}}
\item \href{#method-Regressor-fit_predict}{\code{Regressor$fit_predict()}}
\item \href{#method-Regressor-update}{\code{Regressor$update()}}
\item \href{#method-Regressor-clone}{\code{Regressor$clone()}}
}
}
\if{html}{\out{
<details><summary>Inherited methods</summary>
<ul>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_B"><a href='../../learningmachine/html/Base.html#method-Base-get_B'><code>learningmachine::Base$get_B()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_activ"><a href='../../learningmachine/html/Base.html#method-Base-get_activ'><code>learningmachine::Base$get_activ()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_engine"><a href='../../learningmachine/html/Base.html#method-Base-get_engine'><code>learningmachine::Base$get_engine()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_level"><a href='../../learningmachine/html/Base.html#method-Base-get_level'><code>learningmachine::Base$get_level()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_method"><a href='../../learningmachine/html/Base.html#method-Base-get_method'><code>learningmachine::Base$get_method()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_model"><a href='../../learningmachine/html/Base.html#method-Base-get_model'><code>learningmachine::Base$get_model()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_name"><a href='../../learningmachine/html/Base.html#method-Base-get_name'><code>learningmachine::Base$get_name()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_nb_hidden"><a href='../../learningmachine/html/Base.html#method-Base-get_nb_hidden'><code>learningmachine::Base$get_nb_hidden()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_nodes_sim"><a href='../../learningmachine/html/Base.html#method-Base-get_nodes_sim'><code>learningmachine::Base$get_nodes_sim()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_params"><a href='../../learningmachine/html/Base.html#method-Base-get_params'><code>learningmachine::Base$get_params()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_pi_method"><a href='../../learningmachine/html/Base.html#method-Base-get_pi_method'><code>learningmachine::Base$get_pi_method()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_seed"><a href='../../learningmachine/html/Base.html#method-Base-get_seed'><code>learningmachine::Base$get_seed()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="get_type"><a href='../../learningmachine/html/Base.html#method-Base-get_type'><code>learningmachine::Base$get_type()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_B"><a href='../../learningmachine/html/Base.html#method-Base-set_B'><code>learningmachine::Base$set_B()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_activ"><a href='../../learningmachine/html/Base.html#method-Base-set_activ'><code>learningmachine::Base$set_activ()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_engine"><a href='../../learningmachine/html/Base.html#method-Base-set_engine'><code>learningmachine::Base$set_engine()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_level"><a href='../../learningmachine/html/Base.html#method-Base-set_level'><code>learningmachine::Base$set_level()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_method"><a href='../../learningmachine/html/Base.html#method-Base-set_method'><code>learningmachine::Base$set_method()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_model"><a href='../../learningmachine/html/Base.html#method-Base-set_model'><code>learningmachine::Base$set_model()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_nb_hidden"><a href='../../learningmachine/html/Base.html#method-Base-set_nb_hidden'><code>learningmachine::Base$set_nb_hidden()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_nodes_sim"><a href='../../learningmachine/html/Base.html#method-Base-set_nodes_sim'><code>learningmachine::Base$set_nodes_sim()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_pi_method"><a href='../../learningmachine/html/Base.html#method-Base-set_pi_method'><code>learningmachine::Base$set_pi_method()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="set_seed"><a href='../../learningmachine/html/Base.html#method-Base-set_seed'><code>learningmachine::Base$set_seed()</code></a></span></li>
<li><span class="pkg-link" data-pkg="learningmachine" data-topic="Base" data-id="summary"><a href='../../learningmachine/html/Base.html#method-Base-summary'><code>learningmachine::Base$summary()</code></a></span></li>
</ul>
</details>
}}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-new"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-new}{}}}
\subsection{Method \code{new()}}{
Create a new object.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$new(
  name = "Regressor",
  type = "regression",
  model = NULL,
  method = NULL,
  X_train = NULL,
  y_train = NULL,
  pi_method = c("none", "splitconformal", "jackknifeplus", "kdesplitconformal",
    "bootsplitconformal", "kdejackknifeplus", "bootjackknifeplus", "surrsplitconformal",
    "surrjackknifeplus"),
  level = 95,
  B = 100,
  nb_hidden = 0,
  nodes_sim = c("sobol", "halton", "unif"),
  activ = c("relu", "sigmoid", "tanh", "leakyrelu", "elu", "linear"),
  engine = NULL,
  params = NULL,
  seed = 123
)}\if{html}{\out{</div>}}
}

\subsection{Returns}{
A new \code{Regressor} object.
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-fit"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-fit}{}}}
\subsection{Method \code{fit()}}{
Fit model to training set
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$fit(X, y, type_split = c("stratify", "sequential"), ...)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{X}}{a matrix of covariates (i.e explanatory variables)}

\item{\code{y}}{a vector, the response (i.e variable to be explained)}

\item{\code{type_split}}{type of data splitting for split conformal prediction:
"stratify" (for classical supervised learning) "sequential" (when
the data sequential ordering matters)}

\item{\code{...}}{additional parameters to learning algorithm (see vignettes)}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-predict"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-predict}{}}}
\subsection{Method \code{predict()}}{
Predict model on test set
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$predict(X, ...)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{X}}{a matrix of covariates (i.e explanatory variables)}

\item{\code{...}}{additional parameters}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-fit_predict"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-fit_predict}{}}}
\subsection{Method \code{fit_predict()}}{
Fit model to training set and predict on test set
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$fit_predict(
  X,
  y,
  pct_train = 0.8,
  score = ifelse(is.factor(y), yes = function(preds, y_test) mean(preds == y_test), no =
    function(preds, y_test) sqrt(mean((preds - y_test)^2))),
  level = NULL,
  pi_method = c("none", "splitconformal", "jackknifeplus", "kdesplitconformal",
    "bootsplitconformal", "kdejackknifeplus", "bootjackknifeplus", "surrsplitconformal",
    "surrjackknifeplus"),
  B = 100,
  seed = 123,
  graph = FALSE,
  ...
)}\if{html}{\out{</div>}}
}

}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-update"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-update}{}}}
\subsection{Method \code{update()}}{
update model in an online fashion (for now, only implemented for 'rvfl' models")
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$update(newx, newy, ...)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{newx}}{a vector of new covariates (i.e explanatory variables)}

\item{\code{newy}}{a numeric, the new response's observation (i.e variable to be explained)}

\item{\code{...}}{additional parameters to be passed to the underlying model's method \code{update}}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-Regressor-clone"></a>}}
\if{latex}{\out{\hypertarget{method-Regressor-clone}{}}}
\subsection{Method \code{clone()}}{
The objects of this class are cloneable with this method.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Regressor$clone(deep = FALSE)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{deep}}{Whether to make a deep clone.}
}
\if{html}{\out{</div>}}
}
}
}
